@@ -12,10 +12,10 @@
 #             Devan Franchini <twitch153@gentoo.org>
 #
 
-#===============================================================================              
+#===============================================================================
 #
 # Dependencies
-#                                                   
+#
 #-------------------------------------------------------------------------------
 from __future__ import unicode_literals
 
@@ -76,9 +76,9 @@ AUTOCOMPLETE_TEMPLATE = {
                                   '%(tail)s;a=shortlog;h=refs/heads/'\
                                   '%(branch)s',
                       'sources': (
-                     ('https://git.overlays.gentoo.org/gitroot/%(tail)s', 'git', 
+                     ('https://git.overlays.gentoo.org/gitroot/%(tail)s', 'git',
                       '%(branch)s'),
-                     ('git://git.overlays.gentoo.org/%(tail)s', 'git', 
+                     ('git://git.overlays.gentoo.org/%(tail)s', 'git',
                       '%(branch)s'),
                      ('git+ssh://git@git.overlays.gentoo.org/%(tail)s', 'git',
                       '%(branch)s')
@@ -116,7 +116,7 @@ class Interactive(object):
         self.overlay = {}
         self.overlays = []
         self.overlays_available = self.layman_inst.get_available()
-        self.supported_types = self.layman_inst.supported_types().keys()
+        self.supported_types = list(self.layman_inst.supported_types())
 
 
     def args_parser(self):
@@ -193,7 +193,7 @@ class Interactive(object):
                     self.output.notice('')
                     self.update_required()
                     self.output.notice('')
-                    
+
                 self.get_overlay_components()
                 ovl = Overlay.Overlay(config=self.config, ovl_dict=self.overlay, ignore=1)
                 self.overlays.append((self.overlay['name'], ovl))
@@ -237,7 +237,7 @@ class Interactive(object):
         if 'tar' in type_checks:
             type_checks.remove(type_checks[type_checks.index('tar')])
             type_checks.insert(len(type_checks), '.tar')
-                
+
         if 'bzr' in type_checks:
             type_checks.remove(self.supported_types[type_checks.index('bzr')])
             type_checks.insert(len(type_checks), 'bazaar')
@@ -343,14 +343,16 @@ class Interactive(object):
 
         for i in range(1, source_amount + 1):
             sources = []
+            correct = False
             if source_amount > 1:
                 msg = 'Define source[%(i)s]\'s URL: ' % ({'i': str(i)})
                 sources.append(get_input(msg))
 
                 ovl_type = self.guess_overlay_type(sources[0])
-                msg = 'Is %(type)s the correct overlay type?: '\
-                    % ({'type': ovl_type})
-                correct = get_ans(msg)
+                if ovl_type:
+                    msg = 'Is "%(type)s" the correct overlay type?: '\
+                        % ({'type': ovl_type})
+                    correct = get_ans(msg)
                 while not ovl_type or not correct:
                     msg = 'Please provide overlay type: '
                     ovl_type = self.check_overlay_type(\
@@ -368,9 +370,10 @@ class Interactive(object):
                 sources.append(get_input('Define source URL: '))
 
                 ovl_type = self.guess_overlay_type(sources[0])
-                msg = 'Is %(type)s the correct overlay type?: '\
-                       % ({'type': ovl_type})                                                      
-                correct = get_ans(msg)
+                if ovl_type:
+                    msg = 'Is %(type)s the correct overlay type?: '\
+                           % ({'type': ovl_type})
+                    correct = get_ans(msg)
                 while not ovl_type or not correct:
                     msg = 'Please provide overlay type: '
                     ovl_type = self.check_overlay_type(\
@@ -415,7 +418,7 @@ class Interactive(object):
             if component in ('descriptions', 'feeds', 'name', 'owner', 'sources'):
                 getattr(self, 'get_%(comp)s' % ({'comp': component}))()
             else:
-                self.overlay[component] = getattr('get_input')(msg)
+                self.overlay[component] = get_input(msg)
 
 
     def get_overlay_components(self):
@@ -450,7 +453,7 @@ class Interactive(object):
         '''
         try:
             document = ET.parse(path)
-        except xml.etree.ElementTree.ParseError as error:
+        except ET.ParseError as error:
             msg = 'Interactive.read(); encountered error: %(error)s'\
                 % ({'error': error})
             raise Exception(msg)
@@ -487,7 +490,7 @@ class Interactive(object):
                         TEMPLATE = AUTOCOMPLETE_TEMPLATE[i]
                 else:
                     TEMPLATE = AUTOCOMPLETE_TEMPLATE[i]
- 
+
                 self.overlay['homepage'] = TEMPLATE['homepage'] % attrs
 
                 if i in ('bitbucket') and 'git' in (source[1]):
@@ -545,7 +548,7 @@ class Interactive(object):
     def write(self, destination):
         '''
         Writes overlay file to desired location.
-        
+
         @params destination: path & file to write xml to.
         @rtype bool: reflects success or failure to write xml.
         '''
