@@ -30,7 +30,6 @@ import os, os.path
 import sys
 import hashlib
 
-'''
 GPG_ENABLED = False
 try:
     from pygpg.config import GPGConfig
@@ -38,7 +37,7 @@ try:
     GPG_ENABLED = True
 except ImportError:
     pass
-'''
+
 
 from   layman.utils             import encoder
 from   layman.dbbase            import DbBase
@@ -58,16 +57,16 @@ class RemoteDB(DbBase):
         self.detached_urls = []
         self.signed_urls = []
         self.proxies = config.proxies
-        
+
         self.urls  = [i.strip()
             for i in config['overlays'].split('\n') if len(i)]
-        '''
+
         if GPG_ENABLED:
             self.get_gpg_urls()
         else:
             self.output.debug('RemoteDB.__init__(), NOT GPG_ENABLED, '
                 'bypassing...', 2)
-        '''
+
         # add up the lists to load for display, etc.
         # unsigned overlay lists
         paths = [self.filepath(i) + '.xml' for i in self.urls]
@@ -93,8 +92,8 @@ class RemoteDB(DbBase):
         DbBase.__init__(self, config, paths=paths, ignore=ignore,
             ignore_init_read_errors=ignore_init_read_errors)
 
-        #self.gpg = None
-        #self.gpg_config = None
+        self.gpg = None
+        self.gpg_config = None
 
 
     # overrider
@@ -114,12 +113,14 @@ class RemoteDB(DbBase):
         # succeeded reset when a failure is detected
         succeeded = True
         url_lists = [self.urls, self.detached_urls, self.signed_urls]
-        #need_gpg = [False, True, True]
+        need_gpg = [False, True, True]
         # setup the ssl-fetch output map
         connector_output = {
-            'info':  self.output.debug,
+            'info':  self.output.info,
+            'debug': self.output.debug,
             'error': self.output.error,
-            'kwargs-info': {'level': 2},
+            'kwargs-info': {'level': 5},
+            'kwargs-debug': {'level': 2},
             'kwargs-error':{'level': None},
         }
         fetcher = Connector(connector_output, self.proxies, USERAGENT)
@@ -127,11 +128,9 @@ class RemoteDB(DbBase):
         for index in range(0, 3):
             self.output.debug("RemoteDB.cache() index = %s" %str(index), 2)
             urls = url_lists[index]
-            '''
             if need_gpg[index] and len(urls) and self.gpg is None:
                 #initialize our gpg instance
                 self.init_gpg()
-            '''
             # main working loop
             for url in urls:
                 sig = ''
@@ -153,7 +152,6 @@ class RemoteDB(DbBase):
 
                 self.output.debug("RemoteDB.cache() len(olist) = %s"
                     % str(len(olist)), 2)
-                '''
                 # GPG handling
                 if need_gpg[index]:
                     olist, verified = self.verify_gpg(url, sig, olist)
@@ -165,7 +163,7 @@ class RemoteDB(DbBase):
                                                 "Failed-to-verify-sig")
                         self.write_cache(olist, filename)
                         continue
-                '''
+
                 # Before we overwrite the old cache, check that the downloaded
                 # file is intact and can be parsed
                 if isinstance(url, tuple):
@@ -316,9 +314,9 @@ class RemoteDB(DbBase):
             raise IOError('Failed to temporarily cache overlays list in'
                           ' ' + mpath + '\nError was:\n' + str(error))
         return has_updates
-    '''
+
     def verify_gpg(self, url, sig, olist):
-        \'''Verify and decode it.\'''
+        '''Verify and decode it.'''
         self.output.debug("RemoteDB: verify_gpg(), verify & decrypt olist: "
             " %s, type(olist)=%s" % (str(url),str(type(olist))), 2)
         #self.output.debug(olist, 2)
@@ -347,7 +345,7 @@ class RemoteDB(DbBase):
             self.output.error('\tSignature result:' + str(gpg_result.verified))
             olist = ''
         return olist, gpg_result.verified[0]
-    '''
+
 
     def dl_sig(self, url, sig):
         self.output.debug("RemoteDB.dl_sig() url=%s, sig=%s" % (url, sig), 2)
@@ -356,7 +354,7 @@ class RemoteDB(DbBase):
             success = self.write_cache(newsig, sig)
         return success
 
-    '''
+
     def init_gpg(self):
         self.output.debug("RemoteDB.init_gpg(), initializing", 2)
         if not self.gpg_config:
@@ -367,10 +365,10 @@ class RemoteDB(DbBase):
         self.output.debug("RemoteDB.init_gpg(), initialized :D", 2)
 
     def get_gpg_urls(self):
-        \'''Extend paths with gpg signed url listings from the config
+        '''Extend paths with gpg signed url listings from the config
 
         @param paths: list or urls to fetch
-        \'''
+        '''
         #pair up the list url and detached sig url
         d_urls = [i.strip()
             for i in self.config['gpg_detached_lists'].split('\n') if len(i)]
@@ -383,15 +381,3 @@ class RemoteDB(DbBase):
 
         self.signed_urls = [i.strip()
             for i in self.config['gpg_signed_lists'].split('\n') if len(i)]
-    '''
-
-if __name__ == '__main__':
-    import doctest
-
-    # Ignore warnings here. We are just testing
-    from warnings     import filterwarnings, resetwarnings
-    filterwarnings('ignore')
-
-    doctest.testmod(sys.modules[__name__])
-
-    resetwarnings()
