@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #################################################################################
-# EXTENRAL LAYMAN TESTS
+# EXTERNAL LAYMAN TESTS
 #################################################################################
 # File:       external.py
 #
@@ -89,31 +89,20 @@ class AddDeleteEnableDisableFromDB(unittest.TestCase):
         # Add all the overlays in global_overlays.xml.
         for overlay in a.overlays.keys():
             conf_success = conf.add(a.overlays[overlay])
-            if False in conf_success:
+            if conf_success == False:
                 success.append(False)
             else:
                 success.append(True)
 
         # Disable one overlay.
-        conf_success = conf.disable(a.overlays['wrobel'])
-        if False in conf_success:
-            success.append(False)
-        else:
-            success.append(True)
+        self.assertTrue(conf.disable(a.overlays['wrobel']))
 
         # Enable disabled overlay.
-        conf_success = conf.enable(a.overlays['wrobel'])
-        if False in conf_success:
-            success.append(False)
-        else:
-            success.append(True)
+        self.assertTrue(conf.enable(a.overlays['wrobel']))
+
         # Delete all the overlays in global_overlays.xml.
         for overlay in a.overlays.keys():
-            conf_success = conf.delete(a.overlays[overlay])
-            if False in conf_success:
-                success.append(False)
-            else:
-                success.append(True)
+            self.assertTrue(conf.delete(a.overlays[overlay]))
 
         # Clean up.
         os.unlink(makeconf)
@@ -121,13 +110,6 @@ class AddDeleteEnableDisableFromDB(unittest.TestCase):
 
         shutil.rmtree(tmpdir)
 
-        if False in success:
-            success = False
-        else:
-            success = True
-
-        self.assertTrue(success)
-
 
 # Tests archive overlay types (squashfs, tar)
 # http://bugs.gentoo.org/show_bug.cgi?id=304547
@@ -194,7 +176,16 @@ class ArchiveAddRemoveSync(unittest.TestCase):
 
 
     def test(self):
-        for archive in ('squashfs', 'tar'):
+        archives = []
+        try:
+            from layman.overlays.modules.tar.tar import TarOverlay
+            archives.append('tar')
+            from layman.overlays.modules.squashfs.squashfs import SquashfsOverlay
+            archives.append('squashfs')
+        except ImportError:
+            pass
+
+        for archive in archives:
             xml_text, repo_name, temp_archive_path = getattr(self,
                                             "_create_%(archive)s_overlay" %
                                             {'archive': archive})()
@@ -248,19 +239,20 @@ class CLIArgs(unittest.TestCase):
 
         # Test the passed in cli opts on the ArgsParser class:
         a = ArgsParser()
-        test_url = '\n\nhttps://api.gentoo.org/overlays/repositories.xml'
-        self.assertEqual(a['overlays'], test_url)
+        test_url = 'https://api.gentoo.org/overlays/repositories.xml'
+        self.assertTrue(test_url in a['overlays'].split('\n'))
+
         test_keys = ['auto_sync', 'bzr_addopts', 'bzr_command', 'bzr_postsync',
-                     'bzr_syncopts', 'cache', 'clean_tar', 'conf_module',
-                     'conf_type', 'config', 'configdir', 'custom_news_pkg',
-                     'cvs_addopts', 'cvs_command', 'cvs_postsync',
-                     'cvs_syncopts', 'darcs_addopts', 'darcs_command',
-                     'darcs_postsync', 'darcs_syncopts', 'g-common_command',
-                     'g-common_generateopts', 'g-common_postsync',
-                     'g-common_syncopts', 'g-sorcery_command',
-                     'g-sorcery_generateopts', 'g-sorcery_postsync',
-                     'g-sorcery_syncopts', 'git_addopts', 'git_command',
-                     'git_email', 'git_postsync', 'git_syncopts',
+                     'bzr_syncopts', 'cache', 'check_official', 'clean_archive',
+                     'conf_module', 'conf_type', 'config', 'configdir',
+                     'custom_news_pkg', 'cvs_addopts', 'cvs_command',
+                     'cvs_postsync', 'cvs_syncopts', 'darcs_addopts',
+                     'darcs_command', 'darcs_postsync', 'darcs_syncopts',
+                     'g-common_command', 'g-common_generateopts',
+                     'g-common_postsync', 'g-common_syncopts',
+                     'g-sorcery_command', 'g-sorcery_generateopts',
+                     'g-sorcery_postsync', 'g-sorcery_syncopts', 'git_addopts',
+                     'git_command', 'git_email', 'git_postsync', 'git_syncopts',
                      'git_user', 'gpg_detached_lists', 'gpg_signed_lists',
                      'http_proxy', 'https_proxy', 'installed', 'local_list',
                      'make_conf', 'mercurial_addopts', 'mercurial_command',
@@ -268,6 +260,8 @@ class CLIArgs(unittest.TestCase):
                      'news_reporter', 'nocheck', 'overlay_defs', 'overlays',
                      'quietness', 'repos_conf', 'require_repoconfig',
                      'rsync_command', 'rsync_postsync', 'rsync_syncopts',
+                     'squashfs_addopts', 'squashfs_command',
+                     'squashfs_postsync', 'squashfs_syncopts',
                      'storage', 'support_url_updates', 'svn_addopts',
                      'svn_command', 'svn_postsync', 'svn_syncopts',
                      't/f_options', 'tar_command', 'tar_postsync', 'umask',
@@ -450,7 +444,7 @@ class MakeOverlayXML(unittest.TestCase):
         with fileopen(path, 'r') as xml:
             test_line = '    <source type="svn">'\
                         'https://overlays.gentoo.org/svn/dev/wrobel</source>\n'
-            self.assertEqual(xml.readlines()[9], test_line)
+            self.assertTrue(test_line in xml.readlines())
             for line in xml.readlines():
                 print(line, end='')
 
@@ -636,7 +630,7 @@ class RemoteDBCache(unittest.TestCase):
                   }
         config = OptionConfig(my_opts)
         db = RemoteDB(config)
-        self.assertEquals(db.cache(), (True, True))
+        self.assertEqual(db.cache(), (True, True))
 
         db_xml = fileopen(db.filepath(config['overlays']) + '.xml')
 
